import React, { useMemo } from "react";
import { Text, View, StyleSheet } from "react-native";
import BarItem from "./BarItem";
import { DEFAULT_COLORS } from "../consts";
import useDefaultProps from "../Shared/useDefaultProps";
export default function BarGraph(props) {
    var defaultProps = useDefaultProps(props);
    var title = defaultProps.title, titlePosition = defaultProps.titlePosition, barHeight = defaultProps.barHeight, barHolderColor = defaultProps.barHolderColor, barAnimated = defaultProps.barAnimated, barLeftStyle = defaultProps.barLeftStyle, barRightStyle = defaultProps.barRightStyle, barHolderRightStyle = defaultProps.barHolderRightStyle, showDivider = defaultProps.showDivider, dividerInterver = defaultProps.dividerInterver, dividerHeight = defaultProps.dividerHeight, dividerColor = defaultProps.dividerColor, dividerWidth = defaultProps.dividerWidth, percentPosition = defaultProps.percentPosition, percentFixed = defaultProps.percentFixed, enableTouchHighlight = defaultProps.enableTouchHighlight;
    var totalCnt = useMemo(function () {
        var total = 0;
        props.graphData.forEach(function (item, index) {
            total += item.value;
        });
        return total;
    }, [props.graphData]);
    var showTitle = useMemo(function () {
        return props.title !== undefined && props.title !== "";
    }, [props.title]);
    var barDistance = useMemo(function () {
        return props.barDistance === undefined ? 12 : props.barDistance;
    }, [props.barDistance]);
    var barAnimateDelay = useMemo(function () {
        return props.barAnimateDelay === undefined ? 60 : props.barAnimateDelay;
    }, [props.barAnimateDelay]);
    var showLabel = useMemo(function () {
        return props.showLabel === undefined ? true : props.showLabel;
    }, [props.showLabel]);
    var labelPosition = useMemo(function () {
        return props.labelPosition === undefined ? "top" : props.labelPosition;
    }, [props.labelPosition]);
    var labelStlye = useMemo(function () {
        return props.labelStlye === undefined ? null : props.labelStlye;
    }, [props.labelStlye]);
    var showValue = useMemo(function () {
        return props.showValue === undefined ? true : props.showValue;
    }, [props.showValue]);
    var valuePosition = useMemo(function () {
        return props.valuePosition === undefined ? "right" : props.valuePosition;
    }, [props.valuePosition]);
    var valueSuffixCnt = useMemo(function () {
        return props.valueSuffixCnt === undefined ? 1000 : props.valueSuffixCnt;
    }, [props.valueSuffixCnt]);
    var valueSuffixList = useMemo(function () {
        return props.valueSuffixList === undefined ? ["k", "m", "b", "t"] : props.valueSuffixList;
    }, [props.valueSuffixList]);
    return (<View style={props.style}>
			{showTitle && titlePosition === "top" && <Text style={[styles.title, props.titleStyle]}>{title}</Text>}
			{props.graphData.map(function (v, i) {
            var barColor = v.color === undefined ? DEFAULT_COLORS[i % DEFAULT_COLORS.length] : v.color;
            return (<BarItem key={v.label + "_" + i} label={v.label} showLabel={showLabel} labelPosition={labelPosition} labelStlye={labelStlye} index={i} value={v.value} onPress={v.onPress} color={barColor} barHeight={barHeight} barHolderColor={barHolderColor} barDistance={i === 0 ? 0 : barDistance} barAnimated={barAnimated} barAnimateDelay={barAnimateDelay} barLeftStyle={barLeftStyle} barRightStyle={barRightStyle} barHolderRightStyle={barHolderRightStyle} showValue={showValue} valuePosition={valuePosition} valueSuffixCnt={valueSuffixCnt} valueSuffixList={valueSuffixList} totalCnt={totalCnt} showDivider={showDivider} dividerInterver={dividerInterver} dividerHeight={dividerHeight} dividerColor={dividerColor} dividerWidth={dividerWidth} percentPosition={percentPosition} percentFixed={percentFixed} PercentLabelComponent={props.PercentLabelComponent} enableTouchHighlight={enableTouchHighlight}/>);
        })}
			{showTitle && titlePosition === "bottom" && <Text style={[styles.title, props.titleStyle]}>{title}</Text>}
		</View>);
}
var styles = StyleSheet.create({
    title: {
        fontWeight: "bold",
        fontSize: 20,
        textAlign: "center",
        marginVertical: 16,
    },
});
//# sourceMappingURL=BarGraph.js.map