import React, { useCallback, useEffect, useMemo, useRef, useState } from "react";
import { Animated, Easing, Text, TouchableOpacity, StyleSheet, View } from "react-native";
import GraphDivider from "../Shared/GraphDivider";
import PercentLabel from "../Shared/PercentLabel";
export default function BarItem(props) {
    var valPercent = useMemo(function () {
        return Math.round((props.value / props.totalCnt) * 100);
    }, [props.value / props.totalCnt]);
    var _a = useState(false), isTouched = _a[0], setIsTouched = _a[1];
    var _b = useState(0), barWidth = _b[0], setBarWidth = _b[1];
    var animWidth = useRef(new Animated.Value(props.barHeight)).current;
    useEffect(function () {
        if (barWidth <= 0 || props.barAnimated === false) {
            return;
        }
        var w = (barWidth * valPercent) / 100;
        Animated.timing(animWidth, {
            toValue: w + props.barHeight,
            duration: 1000,
            delay: props.barAnimateDelay * (props.index + 1),
            useNativeDriver: false,
            isInteraction: true,
            easing: Easing.out(Easing.exp),
        }).start();
        return function () {
            animWidth.setValue(props.barHeight);
        };
    }, [props.barHeight, props.barAnimated, props.barAnimateDelay, props.index, props.value, props.totalCnt, barWidth]);
    var PercentLabelComponent = props.PercentLabelComponent;
    var PercentLbl = function (lblProps) {
        if (PercentLabelComponent === null || PercentLabelComponent === undefined) {
            return (<PercentLabel value={lblProps.value} valueColor={isTouched ? props.color : undefined} barHeight={props.barHeight} totalCnt={lblProps.total} percentFixed={props.percentFixed} textAlign={props.percentPosition}/>);
        }
        else {
            return <PercentLabelComponent {...lblProps}/>;
        }
    };
    var getValueSuffix = useCallback(function (value, suffixCnt, suffixIdx) {
        var dividing = value / suffixCnt;
        var showUnderNum = value % suffixCnt >= suffixCnt * 0.1;
        if (dividing >= 1) {
            if (dividing < suffixCnt) {
                return dividing.toFixed(showUnderNum ? 1 : 0) + props.valueSuffixList[suffixIdx] + "  ";
            }
            else {
                var nextIdx = suffixIdx + 1;
                if (nextIdx >= props.valueSuffixList.length) {
                    return dividing.toFixed(showUnderNum ? 1 : 0) + props.valueSuffixList[suffixIdx] + "  ";
                }
                else {
                    return getValueSuffix(dividing, suffixCnt, nextIdx);
                }
            }
        }
        else {
            return value.toString();
        }
    }, [props.valueSuffixList]);
    var valueWithSuffix = useMemo(function () {
        if (props.valueSuffixCnt <= 0) {
            return props.value.toLocaleString();
        }
        else {
            var val = getValueSuffix(props.value, props.valueSuffixCnt, 0);
            return val;
        }
    }, [props.value, props.valueSuffixCnt, props.valueSuffixList]);
    var onTouching = useCallback(function (touched) {
        if (props.enableTouchHighlight) {
            setIsTouched(touched);
        }
    }, [props.enableTouchHighlight]);
    var styles = getStyles(props.barHeight, props.barHolderColor, props.color);
    return (<View style={[{ marginTop: props.barDistance }]}>
			
			{props.showLabel && props.labelPosition === "top" && (<Text allowFontScaling={false} numberOfLines={2} style={[styles.labelDefault, props.labelStlye, isTouched && { color: props.color }]}>
					{props.label}
				</Text>)}
			<TouchableOpacity activeOpacity={0.6} onPressIn={function () { return onTouching(true); }} onPressOut={function () { return onTouching(false); }} onPress={function () {
            if (props.onPress !== undefined) {
                props.onPress(props.label, props.value, props.color);
            }
        }}>
				<View style={styles.rowCenter}>
					
					{props.percentPosition === "left" && <PercentLbl value={props.value} total={props.totalCnt} color={props.color}/>}
					<View style={[
            styles.barHolder,
            props.barLeftStyle === "rounded" && styles.roundedLeftBar,
            props.barHolderRightStyle === "rounded" && styles.roundedRightBar,
        ]}>
						<View style={[styles.barHolder, { marginLeft: props.barHeight }]} onLayout={function (event) {
            setBarWidth(event.nativeEvent.layout.width);
        }}>
							{props.showDivider && (<GraphDivider leftPosition={0} dividerInterver={props.dividerInterver} dividerHeight={props.dividerHeight} dividerColor={props.dividerColor} dividerWidth={props.dividerWidth}/>)}
						</View>
						<Animated.View style={[
            styles.barColored,
            {
                width: props.barAnimated ? animWidth : "".concat(valPercent.toFixed(0), "%"),
            },
            props.barLeftStyle === "rounded" && styles.roundedLeftBar,
            props.barRightStyle === "rounded" && styles.roundedRightBar,
        ]}>
							{props.showValue && (<View style={[styles.valueCont, props.valuePosition === "right" && { right: 0 }, props.valuePosition === "left" && { left: 0 }]}>
									<Text allowFontScaling={false} numberOfLines={1} style={styles.valueText}>
										{valueWithSuffix}
										{valPercent >= 5 ? " " : ""}
									</Text>
								</View>)}
						</Animated.View>
					</View>
					{props.percentPosition === "right" && <PercentLbl value={props.value} total={props.totalCnt} color={props.color}/>}
				</View>
			</TouchableOpacity>
			{props.showLabel && props.labelPosition === "bottom" && (<Text allowFontScaling={false} numberOfLines={2} style={[styles.labelDefault, props.labelStlye, isTouched && { color: props.color }]}>
					{props.label}
				</Text>)}
		</View>);
}
var getStyles = function (barHeight, barHolderColor, color) {
    return StyleSheet.create({
        labelDefault: { color: "#999999", fontSize: barHeight / 2 },
        rowCenter: {
            flexDirection: "row",
            alignItems: "center",
        },
        barHolder: {
            flex: 1,
            height: barHeight,
            flexDirection: "row",
            alignItems: "center",
            overflow: "hidden",
            backgroundColor: barHolderColor,
        },
        barColored: {
            position: "absolute",
            height: barHeight,
            backgroundColor: color,
        },
        valueCont: {
            position: "absolute",
            minWidth: barHeight,
            height: barHeight,
            justifyContent: "center",
            alignItems: "center",
        },
        valueText: {
            fontSize: barHeight / 2,
            fontWeight: "bold",
            color: "#F0F0F0",
        },
        roundedLeftBar: {
            borderTopLeftRadius: barHeight / 2,
            borderBottomLeftRadius: barHeight / 2,
        },
        roundedRightBar: {
            borderTopRightRadius: barHeight / 2,
            borderBottomRightRadius: barHeight / 2,
        },
    });
};
//# sourceMappingURL=BarItem.js.map