import React, { useCallback, useMemo, useState } from "react";
import { Text, View, StyleSheet } from "react-native";
import { DEFAULT_COLORS } from "../consts";
import GraphDivider from "../Shared/GraphDivider";
import StackedBarItem from "./StackedBarItem";
import PercentLabel from "../Shared/PercentLabel";
import StackedListItem from "./StackedListItem";
import useDefaultProps from "../Shared/useDefaultProps";
export default function StackedBar(props) {
    var defaultProps = useDefaultProps(props);
    var title = defaultProps.title, titlePosition = defaultProps.titlePosition, barHeight = defaultProps.barHeight, barHolderColor = defaultProps.barHolderColor, barAnimated = defaultProps.barAnimated, barLeftStyle = defaultProps.barLeftStyle, barRightStyle = defaultProps.barRightStyle, barHolderRightStyle = defaultProps.barHolderRightStyle, showDivider = defaultProps.showDivider, dividerInterver = defaultProps.dividerInterver, dividerHeight = defaultProps.dividerHeight, dividerColor = defaultProps.dividerColor, dividerWidth = defaultProps.dividerWidth, percentPosition = defaultProps.percentPosition, percentFixed = defaultProps.percentFixed, enableTouchHighlight = defaultProps.enableTouchHighlight;
    var sumOfValues = useMemo(function () {
        var sum = 0;
        props.graphData.forEach(function (item, index) {
            sum += item.value;
        });
        return sum;
    }, [props.graphData]);
    var showTitle = useMemo(function () {
        return props.title !== undefined && props.title !== "";
    }, [props.title]);
    var showList = useMemo(function () {
        return props.showList === undefined ? true : props.showList;
    }, [props.showList]);
    var listAnimated = useMemo(function () {
        return props.listAnimated === undefined ? true : props.listAnimated;
    }, [props.listAnimated]);
    var _a = useState(0), barWidth = _a[0], setBarWidth = _a[1];
    var PercentLabelComponent = props.PercentLabelComponent;
    var PercentLbl = useCallback(function (lblProps) {
        if (PercentLabelComponent === null || PercentLabelComponent === undefined) {
            return (<PercentLabel value={lblProps.value} valueColor={undefined} barHeight={barHeight} totalCnt={lblProps.total} percentFixed={percentFixed} textAlign={percentPosition}/>);
        }
        else {
            return <PercentLabelComponent {...lblProps}/>;
        }
    }, [barHeight, percentFixed, percentPosition, PercentLabelComponent]);
    var _b = useState(-1), touchedIndex = _b[0], setTouchedIndex = _b[1];
    var onTouching = useCallback(function (index, isTouched) {
        if (enableTouchHighlight) {
            if (isTouched) {
                setTouchedIndex(index);
            }
            else {
                setTouchedIndex(-1);
            }
        }
    }, [enableTouchHighlight]);
    var StackedItem = useCallback(function (item, index) {
        var barColor = item.color === undefined ? DEFAULT_COLORS[index % DEFAULT_COLORS.length] : item.color;
        return (<StackedBarItem key={item.label + "_" + index} index={index} value={item.value} containerWidth={barWidth} color={barColor} totalCnt={props.totalCnt} barHeight={barHeight} barAnimated={barAnimated} barLeftStyle={barLeftStyle === "rounded" && index === 0 ? "rounded" : "square"} barRightStyle={barRightStyle === "rounded" && index === props.graphData.length - 1 ? "rounded" : "square"} isTouched={touchedIndex === index}/>);
    }, [barWidth, props.totalCnt, barHeight, barAnimated, barLeftStyle, barRightStyle, touchedIndex]);
    var ListItem = useCallback(function (_a) {
        var item = _a.item, index = _a.index;
        var barColor = item.color === undefined ? DEFAULT_COLORS[index % DEFAULT_COLORS.length] : item.color;
        if (props.ListItemComponent === undefined || props.ListItemComponent === null) {
            return (<StackedListItem key={item.label + "_" + index} index={index} value={item.value} label={item.label} color={barColor} totalCnt={props.totalCnt} percentPosition={percentPosition} percentFixed={percentFixed} PercentLabelComponent={PercentLbl} onTouching={onTouching} onPress={item.onPress} listAnimated={listAnimated}/>);
        }
        else {
            var ListItemComponent = props.ListItemComponent;
            return (<ListItemComponent key={item.label + "_" + index} index={index} label={item.label} value={item.value} color={barColor} totalCnt={props.totalCnt} onTouching={onTouching} PercentLabelComponent={PercentLbl}/>);
        }
    }, [props.totalCnt, percentPosition, percentFixed, PercentLbl, onTouching, listAnimated, props.ListItemComponent]);
    var styles = getStyles(barHeight, barHolderColor);
    return (<View style={props.style}>
			{showTitle && titlePosition === "top" && <Text style={[styles.title, props.titleStyle]}>{title}</Text>}
			<View style={styles.flexRowVerticalCenter}>
				
				{percentPosition === "left" && <PercentLbl value={sumOfValues} total={props.totalCnt} color={undefined}/>}
				<View style={[
            styles.barHolderStyle,
            barLeftStyle === "rounded" && styles.roundedLeftBar,
            barHolderRightStyle === "rounded" && styles.roundedRightBar,
        ]} onLayout={function (event) {
            setBarWidth(event.nativeEvent.layout.width);
        }}>
					{showDivider && (<GraphDivider leftPosition={0} dividerInterver={dividerInterver} dividerHeight={dividerHeight} dividerColor={dividerColor} dividerWidth={dividerWidth}/>)}
					{barWidth > 0 && props.graphData.map(function (item, index) { return StackedItem(item, index); })}
				</View>
				{percentPosition === "right" && <PercentLbl value={sumOfValues} total={props.totalCnt} color={undefined}/>}
			</View>
			{showList && (<View style={props.listContainerStyle}>
					{props.graphData.map(function (item, index) { return (<ListItem key={index} item={item} index={index}/>); })}
				</View>)}
			{showTitle && titlePosition === "bottom" && <Text style={[styles.title, props.titleStyle]}>{props.title}</Text>}
		</View>);
}
var getStyles = function (barHeight, barHolderColor) {
    return StyleSheet.create({
        title: {
            fontWeight: "bold",
            fontSize: 20,
            textAlign: "center",
            marginVertical: 16,
        },
        flexRowVerticalCenter: { flexDirection: "row", alignItems: "center" },
        barHolderStyle: {
            flexDirection: "row",
            overflow: "hidden",
            flex: 1,
            height: barHeight,
            backgroundColor: barHolderColor,
        },
        roundedLeftBar: {
            borderTopLeftRadius: barHeight / 2,
            borderBottomLeftRadius: barHeight / 2,
        },
        roundedRightBar: {
            borderTopRightRadius: barHeight / 2,
            borderBottomRightRadius: barHeight / 2,
        },
    });
};
//# sourceMappingURL=StackedBar.js.map