import React, { useLayoutEffect, useMemo, useRef } from "react";
import { StyleSheet, Animated, Easing } from "react-native";
export default React.memo(_StackedBarItem);
function _StackedBarItem(props) {
    var valPercent = useMemo(function () {
        return Math.round((props.value / props.totalCnt) * 100);
    }, [props.value / props.totalCnt]);
    var animWidth = useRef(new Animated.Value(0)).current;
    useLayoutEffect(function () {
        if (props.containerWidth <= 0 || props.barAnimated === false) {
            return;
        }
        var w = (props.containerWidth * valPercent) / 100;
        Animated.timing(animWidth, {
            toValue: w,
            duration: 1000,
            delay: 100 + 20 * (props.index + 1),
            useNativeDriver: false,
            isInteraction: true,
            easing: Easing.out(Easing.exp),
        }).start();
        return function () {
            animWidth.setValue(0);
        };
    }, [props.barAnimated, props.index, props.value, props.totalCnt, props.containerWidth]);
    var styles = getStyles(props.barHeight, props.color);
    return (<Animated.View style={[
            styles.colorBarStyle,
            { width: props.barAnimated ? animWidth : (valPercent + "%") },
            props.isTouched && { opacity: 0.4 },
            props.barLeftStyle === "rounded" && styles.roundedLeftBar,
            props.barRightStyle === "rounded" && styles.roundedRightBar,
        ]}/>);
}
var getStyles = function (barHeight, color) {
    return StyleSheet.create({
        colorBarStyle: {
            height: barHeight,
            backgroundColor: color,
        },
        roundedLeftBar: {
            borderTopLeftRadius: barHeight / 2,
            borderBottomLeftRadius: barHeight / 2,
        },
        roundedRightBar: {
            borderTopRightRadius: barHeight / 2,
            borderBottomRightRadius: barHeight / 2,
        },
    });
};
//# sourceMappingURL=StackedBarItem.js.map