import React, { useEffect, useMemo, useRef } from "react";
import { StyleSheet, Animated, Easing, View, Text, TouchableOpacity } from "react-native";
export default React.memo(_StackedListItem);
function _StackedListItem(props) {
    var PercentLabelComponent = props.PercentLabelComponent;
    var canRenderPercentLbl = PercentLabelComponent !== null && PercentLabelComponent !== undefined;
    var animOpacity = useRef(new Animated.Value(0)).current;
    useEffect(function () {
        if (props.listAnimated === false) {
            animOpacity.setValue(1);
            return;
        }
        Animated.timing(animOpacity, {
            toValue: 1,
            duration: 1000,
            delay: 500 + 50 * (props.index + 1),
            useNativeDriver: false,
            isInteraction: true,
            easing: Easing.out(Easing.exp),
        }).start();
        return function () {
            animOpacity.setValue(0);
        };
    }, [props.listAnimated, props.index]);
    var styles = useMemo(function () {
        return getStyles(props.color);
    }, [props.color]);
    return (<TouchableOpacity onPressIn={function () { return props.onTouching(props.index, true); }} onPressOut={function () { return props.onTouching(props.index, false); }} onPress={function () { var _a; return (_a = props.onPress) === null || _a === void 0 ? void 0 : _a.call(props, props.label, props.value, props.color); }}>
			<Animated.View style={[{ opacity: animOpacity }, styles.listItemContainer]}>
				{canRenderPercentLbl && props.percentPosition === "left" && (<PercentLabelComponent value={props.value} total={props.totalCnt} color={props.color}/>)}
				{(props.percentPosition === "right" || props.percentPosition === undefined || props.percentPosition === "none") && (<View style={styles.coloredDot}/>)}
				<View style={styles.textContainer}>
					<Text style={styles.labelStyle}>{props.label}</Text>
					<Text>{props.value}</Text>
				</View>
				{canRenderPercentLbl && props.percentPosition === "right" && (<PercentLabelComponent value={props.value} total={props.totalCnt} color={props.color}/>)}
				{props.percentPosition === "left" && <View style={styles.coloredDot}/>}
			</Animated.View>
		</TouchableOpacity>);
}
var getStyles = function (color) {
    return StyleSheet.create({
        listItemContainer: { paddingVertical: 8, flexDirection: "row", alignItems: "center" },
        coloredDot: { width: 20, height: 20, backgroundColor: color, borderRadius: 24 },
        textContainer: { flex: 1, marginLeft: 16 },
        labelStyle: { fontSize: 16 },
    });
};
//# sourceMappingURL=StackedListItem.js.map